@@ -37,9 +37,9 @@ class Auth:
         else:
             headers = dict(headers)
 
-        payload.update({"version": 38})
+        payload.update({"version": 54})
 
-        data = json.dumps(payload).encode("UTF-8")
+        data = self.websession.json_serialize(payload).encode("UTF-8")
 
         signature = base64.b64encode(
             hmac.new(self.password.encode("UTF-8"), data, hashlib.sha1).digest()
