@@ -15,4 +15,6 @@ ENDPOINT_GET_TRACK_COORDINATES = "gti/public/getTrackCoordinates"
 ENDPOINT_CHECK_POSTAL_CODE = "gti/public/checkPostalCode"
 ENDPOINT_GET_STATION_INFORMATION = "gti/public/getStationInformation"
 ENDPOINT_TARIFF_ZONE_NEIGHBOURS = "gti/public/tariffZoneNeighbours"
+ENDPOINT_TARIFF_META_DATA = "gti/public/tariffMetaData"
 ENDPOINT_TICKET_LIST = "gti/public/ticketList"
+ENDPOINT_SINGLE_TICKET_OPTIMIZER = "gti/public/singleTicketOptimizer"
